@@ -33,13 +33,15 @@ subsystems.
 
 class Cookbook(object):
     '''
-    The Cookbook class is the base class for all cookbooks to be created from.
-    If you over-ride any of the functions, be sure to call the base class
-    functions so that all the good stuff still happens.
-
-    In your subclass you will fill the class-level variable recipe_list with
-    class objects for recipes that you want to run when applying the cookbook.
-    The recipes will be applied in the order they're defined in the list.
+    The Cookbook class is the base class for all cookbooks to be created
+    from.  If you over-ride any of the built-in functions, be sure to
+    call the base class functions so that all the good stuff still
+    happens.  You will probably not need to sub-class any of the base
+    functions in your cookbooks, though.  They will all be called by
+    frycooker as necessary.  All you need to do is to fill the
+    class-level variable recipe_list with class objects for recipes that
+    you want to run when applying the cookbook.  The recipes will be
+    applied in the order they're defined in the list.
 
     Example::
 
@@ -52,20 +54,6 @@ class Cookbook(object):
           recipe_list = [RecipeNginx,
                          RecipeExampleCom]
 
-    All cookbook files should live in a single cookbooks package.  The
-    __init__.py file for this package should import all cookbooks and have a
-    list of them called cookbooks so they can easily be imported by the
-    frycooker program.
-
-    Example::
-
-      from base import CookbookBase
-      from web import CookbookWeb
-
-      cookbooks = {
-          'base': CookbookBase,
-          'web': CookbookWeb
-          }
     '''
     recipe_list = []
 
@@ -74,21 +62,14 @@ class Cookbook(object):
         Initialize the cookbook object with the settings and environment
         dictionaries.
 
-        @type settings: dict
-
-        @param settings: settings dictionary
-
-        @type environment: dict
-
-        @param environment: metadata dictionary
-
-        @type ok_to_be_rude: boolean
-
-        @param ok_to_be_rude: is it ok to interrupt your users?
-
-        @type no_prompt: boolean
-
-        @param no_prompt: should we prompt the user?
+        :type settings: dict
+        :param settings: settings dictionary
+        :type environment: dict
+        :param environment: metadata dictionary
+        :type ok_to_be_rude: boolean
+        :param ok_to_be_rude: is it ok to interrupt your users?
+        :type no_prompt: boolean
+        :param no_prompt: should we prompt the user?
         '''
         self.recipes = []
         self.ok_to_be_rude = ok_to_be_rude
@@ -126,9 +107,8 @@ class Cookbook(object):
         and beyond the recipe-level data.  Be sure to call the base if you
         override this.
 
-        @type computer: string
-
-        @param computer: computer to apply recipe checks to
+        :type computer: string
+        :param computer: name of computer to apply recipe checks to
         '''
         for recipe in self.recipes:
             recipe.pre_apply_checks(computer)
@@ -139,9 +119,8 @@ class Cookbook(object):
         Override this if there's something you need to do besides just running
         all the recipes.  Be sure to call the base class if you override this.
 
-        @type computer: string
-
-        @param computer: computer to apply recipe to
+        :type computer: string
+        :param computer: name of computer to apply recipe to
         '''
         for recipe in self.recipes:
             recipe.apply(computer)
@@ -151,9 +130,8 @@ class Cookbook(object):
         Run the apply process for the computer.  This is usually just called
         from frycooker.
 
-        @type computer: string
-
-        @param computer: computer to apply recipe to
+        :type computer: string
+        :param computer: name of computer to apply recipe to
         '''
         self.pre_apply_checks(computer)
         self.apply(computer)
